#load packages
library("rjags")
library("runjags")
library("arules")

#set working directory
#setwd("")

#Note: the present file is designed as follows.
#First, data preparation and models are run by "sourcing" preexisting scripts (which may be consulted on their own for details)
#Second, the output of these scripts is represented in graphical form.
#The user may "source" the present file to reproduce the Figures presented in the main manuscript.

#gaze
source("dataPreparation.R")
source("gazeMultiple.R")

#choice in ultimatum game
source("dataPreparation.R")
source("choice.R")

#parameter names
labels1 <- c(
  "meHijab",   
  "meMale",    
  
  #simple effects
  "seHijabFemale", 
  "seHijabMale",   
  
  #interaction effects
  "ieHijabMaleVsHijabFemale"
)


labels2 <- c(
  #ME
  "hijab", "male", 
  
  #SE
  "hijab @female", "hijab @male",
  
  #IE
  "hijab\n@male vs @female"
  
 )

#graphical parameters
par(mfrow=c(1,2))
par(mar=c(5, 12, 4, 0), las=1) #c(bottom, left, top, right)

#######################################################################################
#plot graphs
#######################################################################################
t1 <- PostDistGaze[labels1, ] 

mainPlot="eye contact"
xlabPlot="difference in %"

#variance of hyperparameters estimated
t1$rown <- nrow(t1):1


plot(t1$X50.,t1$rown, pch=20, cex=2,
     xlim=c(min(t1$X2.5., t1$X97.5.), 
            max(t1$X2.5., t1$X97.5.)),
     ylim=c(min(t1$rown)-0.5, max(t1$rown)+0.5),
     yaxt="n", xlab=xlabPlot, ylab="",
     main=mainPlot,
     cex.main=1.4)
segments(t1$X2.5.,t1$rown, t1$X97.5.,t1$rown)
segments(t1$X5.,t1$rown, t1$X95.,t1$rown, lwd=3)
abline(v=0, lty=2)
mtext(labels2            , side=2, at=t1$rown, cex=1.1, line=1, las=2)
# mtext(c(rep("", 11), labels2[12:length(unique(labels2))]), side=2, at=t1$rown-0.2, cex=1.1, line=1, las=2)

mtext("main effects",        side=2, at=nrow(t1)+0.4, cex=1.5, line=1, las=2, font = 2)
mtext("simple effects",      side=2, at=(nrow(t1)+0.4)-2, cex=1.5, line=1, las=2, font = 2)
mtext("interaction effect", side=2, at=(nrow(t1)+0.4)-2-2, cex=1.5, line=1, las=2, font = 2)
# mtext(c(ssGaze, rep("", 6)), side=4, at=t1$rown, cex=0.8, line=0.2, las=2)




#######################################################################################
#######################################################################################
par(mar=c(5, 6, 4, 6), las=1) #c(bottom, left, top, right)
t1 <- PostDistChoice[labels1, ]*-1 

mainPlot="chooses 1-9 division in game"
xlabPlot="difference in %"

#variance of hyperparameters estimated
t1$rown <- nrow(t1):1


plot(t1$X50.,t1$rown, pch=20, cex=2,
     xlim=c(min(t1$X2.5., t1$X97.5.), 
            max(t1$X2.5., t1$X97.5.)),
     ylim=c(min(t1$rown)-0.5, max(t1$rown)+0.5),
     yaxt="n", xlab=xlabPlot, ylab="",
     main=mainPlot,
     cex.main=1.4)
segments(t1$X2.5.,t1$rown, t1$X97.5.,t1$rown)
segments(t1$X5.,t1$rown, t1$X95.,t1$rown, lwd=3)
abline(v=0, lty=2)
# mtext(labels2, side=2, at=t1$rown, cex=1.1, line=1, las=2)
# # 
# mtext("main effects",        side=2, at=nrow(t1)+0.4, cex=1.5, line=1, las=2, font = 2)
# mtext("simple effects",      side=2, at=(nrow(t1)+0.4)-2, cex=1.5, line=1, las=2, font = 2)
# mtext("interaction effect", side=2, at=(nrow(t1)+0.4)-2-2, cex=1.5, line=1, las=2, font = 2)
# mtext(c(ssChoice, rep("", 6)), side=4, at=t1$rown, cex=0.8, line=0.2, las=2)




#######################################################################################
#plot remaining model parameters
#######################################################################################
##gaze
par(mfrow=c(1,2))

par(mar=c(5, 12, 4, 2), las=1) #c(bottom, left, top, right)

t1 <- PostDistGaze[grep("mu", rownames(PostDistGaze)), ]

mainPlot="eye contact"
xlabPlot="%"

#variance of hyperparameters estimated
t1$rown <- nrow(t1):1


plot(t1$X50.,t1$rown, pch=20, cex=2,
     xlim=c(min(t1$X2.5., t1$X97.5.), 
            max(t1$X2.5., t1$X97.5.)),
     ylim=c(min(t1$rown)-0.5, max(t1$rown)+0.5),
     yaxt="n", xlab=xlabPlot, ylab="",
     main=mainPlot,
     cex.main=1.4)
segments(t1$X2.5.,t1$rown, t1$X97.5.,t1$rown)
segments(t1$X5.,t1$rown, t1$X95.,t1$rown, lwd=3)
abline(v=0, lty=2)
mtext(rownames(t1)            , side=2, at=t1$rown, cex=1.1, line=1, las=2)
abline(v=t1[1,"X50."], lty=1, lwd=3, col="blue")

#choice in game
t1 <- 100-PostDistChoice[grep("mu", rownames(PostDistChoice)), ]

mainPlot="chooses 1-9 division in game"
xlabPlot="%"

#variance of hyperparameters estimated
t1$rown <- nrow(t1):1


plot(t1$X50.,t1$rown, pch=20, cex=2,
     xlim=c(min(t1$X2.5., t1$X97.5.), 
            max(t1$X2.5., t1$X97.5.)),
     ylim=c(min(t1$rown)-0.5, max(t1$rown)+0.5),
     yaxt="n", xlab=xlabPlot, ylab="",
     main=mainPlot,
     cex.main=1.4)
segments(t1$X2.5.,t1$rown, t1$X97.5.,t1$rown)
segments(t1$X5.,t1$rown, t1$X95.,t1$rown, lwd=3)
abline(v=0, lty=2)
mtext(rownames(t1)            , side=2, at=t1$rown, cex=1.1, line=1, las=2)
abline(v=t1[1,"X50."], lty=1, lwd=3, col="blue")

