#load data
#setwd("")
d <- read.csv("dataSpring2019_forPublication.csv") #the data pertain to Study 2, Experiment 1

#poststratify
library(arules)

#post-stratify to prevent bias in the estimation of population estimates (see main manuscript for the rationale)
ps <- read.csv("2018samples_sexAge.csv") #the data pertain to the studies published in 
#Aranguren, Madrisotti and Durmaz-Martins (Journal of Ethnic and Migration Studies, 2021) and 
#Aranguren, Madrisotti, Durmaz-Martins et al. (PLOS ONE, 2021) 

ps <- ps[ps$age>=18, ] #if present, eliminate participants aged less than 18

##discretize age into three categories with approximately equal frequency
ps$age.d <- discretize(ps$age, breaks=3, method="frequency")
###inspect output
table(ps$age.d)
table(ps$age.d, ps$sample)


##apply the resulting breaks to the experiment's sample
d$age.d <- discretize(d$age, breaks=c(-Inf, 27, 41, Inf), method="fixed", 
                      labels=c("18-26", "27-40", "41-"))
###inspect output
table(d$age.d)

##create tables indicating the proportion of participants in each age category, by sex
t1 <- prop.table(table(ps$age.d, ps$sex))
t2 <- prop.table(table(d$age.d,  d$sex))

t1
t2

#compute weights: population proportion/sample proportion
wf1 <- t1[1]/t2[1]    #wf1=weight: female, age group 1
wf2 <- t1[2]/t2[2]
wf3 <- t1[3]/t2[3]
wm1 <- t1[4]/t2[4]    #wm1=weight: male, age group 1
wm2 <- t1[5]/t2[5]
wm3 <- t1[6]/t2[6]

#assign weights
d$weight <- NA
#labels=c("18-26", "27-40", "41-")

d$weight[d$sex=="f" & d$age.d=="18-26"] <- wf1
d$weight[d$sex=="f" & d$age.d=="27-40"] <- wf2
d$weight[d$sex=="f" & d$age.d=="41-"  ] <- wf3

d$weight[d$sex=="m" & d$age.d=="18-26"] <- wm1
d$weight[d$sex=="m" & d$age.d=="27-40"] <- wm2
d$weight[d$sex=="m" & d$age.d=="41-"  ] <- wm3

sum(d$weight) #must sum to the sample size
nrow(d)

##discretize education and income into two groups of equal frequency
#inc group 

d$eduGroup <- discretize(d$edu, method = "frequency", breaks=2)
table(d$eduGroup)

d$incGroup <- discretize(d$inc, method = "frequency", breaks=2)
table(d$incGroup)

d$ageGroup <- d$age.d