#select outcome 

d$y1 <- d$gazeRate1
d$y2 <- d$gazeRate2
d$y3 <- d$gazeRate3
d$y4 <- d$gazeRate4

#visualize data (condition*sex)
par(mfrow=c(2,2))
boxplot(y1 ~ cond * sex, data=d, main="gr slot1 speaker")
boxplot(y2 ~ cond * sex, data=d, main="gr slot2 listener")
boxplot(y3 ~ cond * sex, data=d, main="gr slot3 speaker")
boxplot(y4 ~ cond * sex, data=d, main="gr slot4 listener")

#create a single data frame in "long format"
d1 <- d[, c("id", "cond", "sex", "station", "ageGroup", "eduGroup", "incGroup", "muslim", "y1", "weight")]
d2 <- d[, c("id", "cond", "sex", "station", "ageGroup", "eduGroup", "incGroup", "muslim", "y2", "weight")]
d3 <- d[, c("id", "cond", "sex", "station", "ageGroup", "eduGroup", "incGroup", "muslim", "y3", "weight")]
d4 <- d[, c("id", "cond", "sex", "station", "ageGroup", "eduGroup", "incGroup", "muslim", "y4", "weight")]

colnames(d1) <- c("id", "cond", "sex", "station", "ageGroup", "eduGroup", "incGroup", "muslim","y", "weight")
colnames(d2) <- c("id", "cond", "sex", "station", "ageGroup", "eduGroup", "incGroup", "muslim","y", "weight")
colnames(d3) <- c("id", "cond", "sex", "station", "ageGroup", "eduGroup", "incGroup", "muslim","y", "weight")
colnames(d4) <- c("id", "cond", "sex", "station", "ageGroup", "eduGroup", "incGroup", "muslim","y", "weight")

#create a categorical variable to control the overall mean due to role in the conversation
d1$outcome <- 1 #participant in the role of speaker 
d2$outcome <- 2 #of listener
d3$outcome <- 1
d4$outcome <- 2

dd <- rbind(d1, d2, d3, d4)
head(dd)
tail(dd)

#suppress missing values
d <- dd[!is.na(dd$y), ]
head(d)

#no values must equal 0 or 1
d$y[d$y==1] <- 0.999
d$y[d$y==0] <- 0.001

##select data
y=d$y

n=length(y)

sex=as.factor(d$sex)
n.sex=length(unique(sex))

cond=as.factor(d$cond)
n.cond=length(unique(cond))

ageGroup=as.factor(d$ageGroup)
n.ageGroup=length(unique(ageGroup))

eduGroup=as.factor(d$eduGroup)
n.eduGroup=length(unique(eduGroup))

incGroup=as.factor(d$incGroup)
n.incGroup=length(unique(incGroup))

station=as.factor(d$station) 
n.station=length(unique(station))

muslim=as.factor(d$muslim)
n.muslim=length(unique(muslim))

outcome=as.factor(d$outcome)
n.outcome=length(unique(outcome))

Subj=as.factor(as.character(d$id))
n.Subj=length(unique(Subj))

weight=d$weight

yMean=mean(y, na.rm=T)
ySD=sd(y, na.rm=T)


datalist <- list(y=y, n=n, #outcome
                 ageGroup=ageGroup, n.ageGroup=n.ageGroup,
                 eduGroup=eduGroup, n.eduGroup=n.eduGroup,
                 incGroup=incGroup, n.incGroup=n.incGroup,
                 station=station, n.station=n.station,
                 sex=sex, n.sex=n.sex,
                 cond=cond, n.cond=n.cond
                 ,
                 muslim=muslim, n.muslim=n.muslim,
                 outcome=outcome, n.outcome=n.outcome,
                 Subj=Subj, n.Subj=n.Subj,
                 weight=weight
                 )
datalist
#source model script 
source("dbetaScriptMultipleWeights.R")

#source parameters list
source("parameterSelection3.R")

library(rjags)
library(runjags)
#run simulation
JagsOutput <- run.jags(method="parallel",
                       model="JagsModel",
                       monitor=MyParameters, 
                       data=datalist,
                       n.chains=3,
                       sample=10000,
                       thin=1,
                       summarise=F,
                       plots=F)

#source output processing
source("modelOutput.R")

#table with 95% central posterior intervals
PostDistGaze <- q1*100

print(round(q1, digits=4))
write.csv(PostDistGaze, "PostDistGaze.csv")

